@@ -23,7 +23,7 @@
 /**
  * SECTION:gfileinfo
  * @short_description: File Information and Attributes
- * @include: gio.h
+ * @include: gio/gio.h
  * @see_also: #GFile, <link linkend="gio-GFileAttribute">GFileAttribute</link>
  * 
  * Functionality for manipulating basic metadata for files. #GFileInfo
@@ -38,16 +38,27 @@
  * stream, use g_file_input_stream_query_info() or 
  * g_file_output_stream_query_info() (or their async variants).
  *
+ * To change the actual attributes of a file, you should then set the 
+ * attribute in the #GFileInfo and call g_file_set_attributes_from_info() 
+ * or g_file_set_attributes_async() on a GFile.
+ *
+ * However, not all attributes can be changed in the file. For instance, 
+ * the actual size of a file cannot be changed via g_file_info_set_size(). 
+ * You may call g_file_query_settable_attributes() and 
+ * g_file_query_writable_namespaces() to discover the settable attributes 
+ * of a particular file at runtime.
+ *
  * #GFileAttributeMatcher allows for searching through a #GFileInfo for 
  * attributes.
  **/
 
-#include <config.h>
+#include "config.h"
 
 #include <string.h>
 
 #include "gfileinfo.h"
 #include "gfileattribute-priv.h"
+#include "gicon.h"
 #include "glibintl.h"
 
 #include "gioalias.h"
@@ -224,9 +235,8 @@ g_file_info_finalize (GObject *object)
 
   if (info->mask != NO_ATTRIBUTE_MASK)
     g_file_attribute_matcher_unref (info->mask);
-  
-  if (G_OBJECT_CLASS (g_file_info_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_file_info_parent_class)->finalize) (object);
+
+  G_OBJECT_CLASS (g_file_info_parent_class)->finalize (object);
 }
 
 static void
@@ -333,7 +343,6 @@ g_file_info_set_attribute_mask (GFileInfo             *info,
   int i;
   
   g_return_if_fail (G_IS_FILE_INFO (info));
-  g_return_if_fail (mask != NULL);
   
   if (mask != info->mask)
     {
@@ -1305,7 +1314,7 @@ g_file_info_get_icon (GFileInfo *info)
   
   value = g_file_info_find_value (info, attr);
   obj = _g_file_attribute_value_get_object (value);
-  if (obj != NULL && G_IS_ICON (obj))
+  if (G_IS_ICON (obj))
     return G_ICON (obj);
   return NULL;
 }
@@ -2025,7 +2034,9 @@ static gboolean
 g_file_attribute_matcher_matches_id (GFileAttributeMatcher *matcher,
                                      guint32                id)
 {
-  g_return_val_if_fail (matcher != NULL, FALSE);
+  /* We return a NULL matcher for an empty match string, so handle this */
+  if (matcher == NULL)
+    return FALSE;
   
   if (matcher->all)
     return TRUE;
