@@ -20,11 +20,13 @@
  * Author: Alexander Larsson <alexl@redhat.com>
  */
 
-#include <config.h>
+#include "config.h"
 
 #include <glib.h>
 #include <glocalfileenumerator.h>
 #include <glocalfileinfo.h>
+#include <glocalfile.h>
+#include <gioerror.h>
 #include <string.h>
 #include <stdlib.h>
 #include "glibintl.h"
@@ -127,9 +129,8 @@ g_local_file_enumerator_finalize (GObject *object)
     }
 
   free_entries (local);
-  
-  if (G_OBJECT_CLASS (g_local_file_enumerator_parent_class)->finalize)
-    (*G_OBJECT_CLASS (g_local_file_enumerator_parent_class)->finalize) (object);
+
+  G_OBJECT_CLASS (g_local_file_enumerator_parent_class)->finalize (object);
 }
 
 
@@ -180,20 +181,21 @@ convert_file_to_io_error (GError **error,
         }
     }
   
-  g_set_error (error, G_IO_ERROR,
-	       new_code,
-	       "%s", file_error->message);
+  g_set_error_literal (error, G_IO_ERROR,
+                       new_code,
+                       file_error->message);
 }
 #endif
 
 GFileEnumerator *
-_g_local_file_enumerator_new (const char           *filename,
+_g_local_file_enumerator_new (GLocalFile *file,
 			      const char           *attributes,
 			      GFileQueryInfoFlags   flags,
 			      GCancellable         *cancellable,
 			      GError              **error)
 {
   GLocalFileEnumerator *local;
+  char *filename = g_file_get_path (G_FILE (file));
 
 #ifdef USE_GDIR
   GError *dir_error;
@@ -208,6 +210,7 @@ _g_local_file_enumerator_new (const char           *filename,
 	  convert_file_to_io_error (error, dir_error);
 	  g_error_free (dir_error);
 	}
+      g_free (filename);
       return NULL;
     }
 #else
@@ -219,18 +222,21 @@ _g_local_file_enumerator_new (const char           *filename,
     {
       errsv = errno;
 
-      g_set_error (error, G_IO_ERROR,
-		   g_io_error_from_errno (errsv),
-		   "%s", g_strerror (errsv));
+      g_set_error_literal (error, G_IO_ERROR,
+                           g_io_error_from_errno (errsv),
+                           g_strerror (errsv));
+      g_free (filename);
       return NULL;
     }
 
 #endif
   
-  local = g_object_new (G_TYPE_LOCAL_FILE_ENUMERATOR, NULL);
+  local = g_object_new (G_TYPE_LOCAL_FILE_ENUMERATOR,
+                        "container", file,
+                        NULL);
 
   local->dir = dir;
-  local->filename = g_strdup (filename);
+  local->filename = filename;
   local->matcher = g_file_attribute_matcher_new (attributes);
   local->flags = flags;
   
